==> go.php?file=PhoenixStyle1.54702.zip: PhoenixStyleMod_Firelands/Localization/localization-ruRU.lua <==
﻿if GetLocale() == "ruRU" then


function psfirellocale()

psfirellastmoduleloadtxt	= "Огненные просторы"

psfirelgot			= "Получили"
psfirelgotm			= "получили"
psfirelwhogot			= "Кто получил"
psfireltotal			= "общее"
psfirelgotinm			= "попал в"
psfirelgotinf			= "попала в"
psfirediedfrom			= "умер от"
psfirehealedhimself		= "отлечился"
psfireldamagefrom		= "Урон от"
psfiretxtopt512			= "|tip2 Сколько лечения босс получил от |sid99332|id"
psfiretxtopt515			= "|tip1 Если кто лишний получил урон от |sid100833|id - показывать кто танчил адда и прочее инфо (|cffff0000героич.|r)"
psfiretxtopt516			= "|tip1 Если более 1 чел. получили урон от |sid100838|id - выдавать инфо в чат (|cffff0000героич.|r)"
psfiretxtopt517			= "|tip2 Кто использовал таунты против Пеплопрядов-ткачей (детальнее в 'инфо по ходу боя')"
psfiretxtopt518			= "|tip2 Сколько раз Пеплопряды-трутни получили |sid100634|id"
psfiretxtopt522			= "|tip2 Сколько раз Жидкие обсидианы использовали |sid99875|id"
psfiretxtopt533			= "|tip1 Сообщать если |sid100359|id получил НЕ игрок"
psfiretxtopt544			= "|tip2 Кто прервал |sid99947|id нанося урон адду (общее)"
psfiretxtopt551			= "|tip1 Если игрок умер от кристалла с |sid99403|id - отображаться инфо (кто обновил стаки - |cffff0000героич.|r)"
psfiretxtopt552			= "|tip1 Если игрок убит от |sid99353|id с |sid99403|id - отображать инфо (кто обновил стаки - |cffff0000героич.|r)"
psfiretxtopt553			= "|tip1 Показывать на ком был |sid99516|id если с ним не сбежались (|cffff0000героич.|r)"
psfiretxtopt561			= "|tip1 Кто нанес урон с помощью |sid98620|id"
psfiretxtopt562			= "|tip2 Кто нанес урон с помощью |sid98620|id (общее)"
psfiretxtopt563			= "|tip1 Кто не разделил урон от |sid100214|id (иключены рейдеры с/после 7 сек |sid100215|id)"
psfiretxtopt564			= "|tip2 Кто не разделил урон от |sid100214|id (иключены рейдеры с/после 7 сек |sid100215|id) - общее"
psfiretxtopt571			= "|tip1 Кто взорвал |sid98164|id если кто-то умер от нее (|cffff0000проверка по близости, нет 100% точности|r)"
psfiretxtopt572			= "|tip1 Нанесенный урон по Живым Метеорам, если более 250К (возможно лишний урон)"
psfiretxtopt573			= "|tip1 После |sid100259|id кто наносил урон и станы по аддам"
psfiretxtopt574			= "|tip2 |sid101233|id - кто получил урон при появлении, сразу не отбежал"


psfiretxtoptt533		= "|s4id100359|id получил не игрок! Бафф на"
psfiretxtoptt544		= "|s4id99947|id прервали"
psfiretimes			= "раз"
psfirebaleroccrystal		= "Кристалл"
psfirenotsure			= "не точно"
psfirewith			= "с"
psfireby			= "от" --от
psfirewhodied			= "инфо о смертях"
psfireintershanox		= "Прервал"
psfirebabah			= "взорвал"
psfirebabah2			= "Атак по игрокам |s4id98620,100215,100216,100217|id"
psfiremajodamag1		= "Все получили урон!"
psfiremajodamag2		= "|s4id98474,100212,100213,100214|id без урона по"
psfiremajodamag3		= "без урона по"
psfiremaybeexcessd		= "Возможно лишний урон по"
psfireno			= "БЕЗ"
psfirefixate1			= "последний был %s сек назад на"
psfirediddamageto		= "Урон по"
psfiredamshared			= "взрыв зацепил"
psfireshanaddopt1		= "Аое от копья"
psfireshanaddopt2		= "урон от копья"
psfireshanaddopt3		= "лишний"
psfiretauntseff			= "Таунты против Пеплопрядов-ткачей (необходимые)"
psfiretauntseff2		= "Таунты против Пеплопрядов-ткачей"
psfireconsumeadd		= "Пеплопряды-трутни получили |sid100634|id"


end


end

==> go.php?file=PhoenixStyle1.54802.zip: PhoenixStyleMod_Firelands/Localization/localization-ruRU.lua <==
﻿if GetLocale() == "ruRU" then


function psfirellocale()

psfirellastmoduleloadtxt	= "Огненные просторы"

psfirelgot			= "Получили"
psfirelgotm			= "получили"
psfirelwhogot			= "Кто получил"
psfireltotal			= "общее"
psfirelgotinm			= "попал в"
psfirelgotinf			= "попала в"
psfirediedfrom			= "умер от"
psfirehealedhimself		= "отлечился"
psfireldamagefrom		= "Урон от"
psfiretxtopt512			= "|tip2 Сколько лечения босс получил от |sid99332|id"
psfiretxtopt515			= "|tip1 Если кто лишний получил урон от |sid100833|id - показывать кто танчил адда и прочее инфо (|cffff0000героич.|r)"
psfiretxtopt516			= "|tip1 Если более 1 чел. получили урон от |sid100838|id - выдавать инфо в чат (|cffff0000героич.|r)"
psfiretxtopt517			= "|tip2 Кто использовал таунты против Пеплопрядов-ткачей (детальнее в 'инфо по ходу боя')"
psfiretxtopt518			= "|tip2 Сколько раз Пеплопряды-трутни получили |sid100634|id"
psfiretxtopt522			= "|tip2 Сколько раз Жидкие обсидианы использовали |sid99875|id"
psfiretxtopt533			= "|tip1 Сообщать если |sid100359|id получил НЕ игрок"
psfiretxtopt544			= "|tip2 Кто прервал |sid99947|id нанося урон адду (общее)"
psfiretxtopt551			= "|tip1 Если игрок умер от кристалла с |sid99403|id - отображаться инфо (кто обновил стаки - |cffff0000героич.|r)"
psfiretxtopt552			= "|tip1 Если игрок убит от |sid99353|id с |sid99403|id - отображать инфо (кто обновил стаки - |cffff0000героич.|r)"
psfiretxtopt553			= "|tip1 Показывать на ком был |sid99516|id если с ним не сбежались (|cffff0000героич.|r)"
psfiretxtopt561			= "|tip1 Кто нанес урон с помощью |sid98620|id"
psfiretxtopt562			= "|tip2 Кто нанес урон с помощью |sid98620|id (общее)"
psfiretxtopt563			= "|tip1 Кто не разделил урон от |sid100214|id (иключены рейдеры с/после 7 сек |sid100215|id)"
psfiretxtopt564			= "|tip2 Кто не разделил урон от |sid100214|id (иключены рейдеры с/после 7 сек |sid100215|id) - общее"
psfiretxtopt571			= "|tip1 Кто взорвал |sid98164|id если кто-то умер от нее (|cffff0000проверка по близости, нет 100% точности|r)"
psfiretxtopt572			= "|tip1 Нанесенный урон по Живым Метеорам, если более 250К (возможно лишний урон)"
psfiretxtopt573			= "|tip1 После |sid100259|id кто наносил урон и станы по аддам"
psfiretxtopt574			= "|tip2 |sid101233|id - кто получил урон при появлении, сразу не отбежал"


psfiretxtoptt533		= "|s4id100359|id получил не игрок! Бафф на"
psfiretxtoptt544		= "|s4id99947|id прервали"
psfiretimes			= "раз"
psfirebaleroccrystal		= "Кристалл"
psfirenotsure			= "не точно"
psfirewith			= "с"
psfireby			= "от" --от
psfirewhodied			= "инфо о смертях"
psfireintershanox		= "Прервал"
psfirebabah			= "взорвал"
psfirebabah2			= "Атак по игрокам |s4id98620,100215,100216,100217|id"
psfiremajodamag1		= "Все получили урон!"
psfiremajodamag2		= "|s4id98474,100212,100213,100214|id нет урона по"
psfiremajodamag3		= "нет урона по"
psfiremaybeexcessd		= "Возможно лишний урон по"
psfireno			= "БЕЗ"
psfirefixate1			= "последний был %s сек назад на"
psfirediddamageto		= "Урон по"
psfiredamshared			= "взрыв зацепил"
psfireshanaddopt1		= "Аое от копья"
psfireshanaddopt2		= "урон от копья"
psfireshanaddopt3		= "лишний"
psfiretauntseff			= "Таунты против Пеплопрядов-ткачей (необходимые)"
psfiretauntseff2		= "Таунты против Пеплопрядов-ткачей"
psfireconsumeadd		= "Пеплопряды-трутни получили |sid100634|id"
psfiretrapragna1		= "Ближайшие к ловушке (до 8 м):"
psfiretrapragna2		= "Никто не был обнаружен в радиусе 8 м."
psfireyard			= "м"
psfirekilledplayer		= "убила игрока!"
psfirekilledplayers		= "убила %s игрока!"
psfiredeadrag			= "УМЕРЛИ"


end


end
